import numpy as np
import h5py

# The file structure is the following:
#   ├── x_coord
#   ├── apparent_res_{mode}_p{order}
#   |   ├── 1_skin
#   |   ├── 2_skin
#   |   ├── 4_skin
#   |   ├── 8_skin
#   |   ├── 8_skin
#   |   └── 10_skin
#   ├── phase_{mode}_p{order}
#   |   ├── 1_skin
#   |   ├── 2_skin
#   |   ├── 4_skin
#   |   ├── 8_skin
#   |   ├── 8_skin
#       └── 10_skin
#
# for mode in {xy, yx} and order in {1,2}

# Open file
f = h5py.File('results/data.h5', 'r')

# Load x-coordinates of stations
x_coord = f['x_coord/'][0].astype(np.float)

# To load the apparent resistivity for xy mode, p1 and 1 skin depth you need to type:
appa_xy_p1_1skin = f['apparent_res_xy_p1/1_skin/'][:]       # load the data

# To load the apparent resistivity for xy mode, p2 and 1 skin depth you need to type:
appa_xy_p2_1skin = f['apparent_res_xy_p2/1_skin/'][:]       # load the data

f.close()
